@@ -1,35 +1,6 @@
 from typing import Dict, Optional, Union
 
-from construct import (
-    ConstructError,
-    Int8sl,
-    Int8ul,
-    Int16sl,
-    Int16ul,
-    Int32sl,
-    Int32ul,
-    Padded,
-)
-
-from nibe.exceptions import DecodeException, EncodeException
-from nibe.parsers import WordSwapped
-
-parser_map = {
-    "u8": Int8ul,
-    "u16": Int16ul,
-    "u32": Int32ul,
-    "s8": Int8sl,
-    "s16": Int16sl,
-    "s32": Int32sl,
-}
-
-parser_map_word_swaped = parser_map.copy()
-parser_map_word_swaped.update(
-    {
-        "u32": WordSwapped(Int32ul),
-        "s32": WordSwapped(Int32sl),
-    }
-)
+from nibe.exceptions import NoMappingException
 
 
 def is_coil_boolean(coil):
@@ -48,6 +19,7 @@ def is_coil_boolean(coil):
 class Coil:
     mappings: Optional[Dict[str, str]]
     reverse_mappings: Optional[Dict[str, str]]
+    _value: Union[int, float, str, None]
 
     def __init__(
         self,
@@ -60,7 +32,6 @@ class Coil:
         unit: str = None,
         mappings: dict = None,
         write: bool = False,
-        word_swap: bool = True,
         **kwargs,
     ):
         assert isinstance(address, int), "Address must be defined"
@@ -71,12 +42,7 @@ class Coil:
             mappings is not None and factor != 1
         ), "When mapping is used factor needs to be 1"
 
-        if word_swap:
-            self.parser = parser_map.get(size)
-        else:
-            self.parser = parser_map_word_swaped.get(size)
-
-        assert self.parser is not None
+        self.size = size
 
         self.address = address
         self.name = name
@@ -105,19 +71,27 @@ class Coil:
 
     def set_mappings(self, mappings):
         if mappings:
-            self.mappings = dict((k, v.upper()) for k, v in mappings.items())
-            self.reverse_mappings = dict((v.upper(), k) for k, v in mappings.items())
+            self.mappings = {k: v.upper() for k, v in mappings.items()}
+            self.reverse_mappings = {v.upper(): k for k, v in mappings.items()}
         else:
             self.mappings = None
             self.reverse_mappings = None
 
     @property
-    def value(self) -> Union[int, float, str]:
+    def value(self) -> Union[int, float, str, None]:
         return self._value
 
     @value.setter
-    def value(self, value: Union[int, float, str]):
-        if self.mappings:
+    def value(self, value: Union[int, float, str, None]):
+        if value is None:
+            self._value = None
+            return
+
+        if self.reverse_mappings:
+            assert isinstance(
+                value, str
+            ), f"Provided value '{value}' is invalid type (str is supported) for {self.name}"
+
             value = value.upper()
             assert (
                 value in self.reverse_mappings
@@ -135,59 +109,31 @@ class Coil:
         self._value = value
 
     @property
-    def raw_value(self) -> bytes:
-        return self._encode(self.value)
+    def has_mappings(self):
+        return self.mappings is not None
 
-    @raw_value.setter
-    def raw_value(self, raw_value: bytes):
-        self.value = self._decode(raw_value)
+    def get_mapping_for(self, value: int):
+        if not self.mappings:
+            raise NoMappingException(f"No mappings defined for {self.name}")
 
-    def _decode(self, raw: bytes) -> Union[int, float, str]:
-        value = self.parser.parse(raw)
         try:
-            self._check_raw_value_bounds(value)
-        except AssertionError as e:
-            raise DecodeException(e)
-        if self.factor != 1:
-            value /= self.factor
-        if self.mappings is None:
-            return value
-
-        mapped_value = self.mappings.get(str(value))
-        if mapped_value is None:
-            raise DecodeException(
+            return self.mappings[str(value)]
+        except KeyError:
+            raise NoMappingException(
                 f"Mapping not found for {self.name} coil for value: {value}"
             )
 
-        return mapped_value
+    def get_reverse_mapping_for(self, value: Union[int, float, str, None]):
+        if not self.reverse_mappings:
+            raise NoMappingException(f"No reverse mappings defined for {self.name}")
 
-    def _encode(self, val: Union[int, float, str]) -> bytes:
         try:
-            if self.reverse_mappings is not None:
-                mapped_value = self.reverse_mappings.get(str(val))
-                if mapped_value is None:
-                    raise EncodeException(
-                        f"Mapping not found for {self.name} coil for value: {val}"
-                    )
-
-                return self._pad(mapped_value)
-
-            if self.factor != 1:
-                val *= self.factor
-
-            self._check_raw_value_bounds(val)
-
-            return self._pad(val)
-        except AssertionError as e:
-            raise EncodeException(e)
-        except ConstructError as e:
-            raise EncodeException(
-                f"Failed to encode {self.name} coil for value: {val}, exception: {e}"
+            return self.reverse_mappings[str(value)]
+        except KeyError:
+            raise NoMappingException(
+                f"Reverse mapping not found for {self.name} coil for value: {value}"
             )
 
-    def _pad(self, value) -> bytes:
-        return Padded(4, self.parser).build(int(value))
-
     def check_value_bounds(self, value):
         if self.min is not None:
             assert (
@@ -199,16 +145,16 @@ class Coil:
                 value <= self.max
             ), f"{self.name} coil value ({value}) is larger than max allowed ({self.max})"
 
-    def _check_raw_value_bounds(self, value):
+    def check_raw_value_bounds(self, value):
         if self.raw_min is not None:
             assert (
                 value >= self.raw_min
-            ), f"{self.name} coil raw value ({value}) is smaller than min allowed({self.raw_min})"
+            ), f"value ({value}) is smaller than min allowed ({self.raw_min})"
 
         if self.raw_max is not None:
             assert (
                 value <= self.raw_max
-            ), f"{self.name} coil raw value ({value}) is larger than max allowed ({self.raw_max})"
+            ), f"value ({value}) is larger than max allowed ({self.raw_max})"
 
     def __repr__(self):
         return f"Coil {self.address}, name: {self.name}, title: {self.title}, value: {self.value}"
